(how-to-guides)=
# 🛠️ How-to Guides


The how-to guides offer a more comprehensive overview of all the tools Ragas
offers and how to use them. This will help you tackle messier real-world
usecases when you're using the framework to help build your own RAG pipelines.

The guides assume you are familiar and confortable with the Ragas basics. If
your not feel free to checkout the [Get Started](../getstarted/index.md)
sections first.

These guides are organized into 3 sections

- [Customisations](./customisations/index.md): How to customise Ragas to use with your system. Things
  like changing the LLMs used underneath are covered here.
- [Applications](./applications/index.md): Shows how to leverage Ragas framework to solve various
  real-world problems that you might be facing too.
- [Integrations](./integrations/index.md): Integrations with other tools like langchain and llamaindex,
  making it super easy to add ragas into your setup.

You can check the entire list bellow 👇

**Index**
:::{toctree}

customisations/index.md
applications/index.md
integrations/index.md
:::
